# fixme:  provide options for CUDA, OpenCL, AVX

%global dot_version 2.1.2
%global ver_sion %(echo %dot_version|tr . _)

Name:		libhmsbeagle
Version:	%dot_version
Release:	1%{?dist}
Summary:	High-performance library for Bayesian and Maximum Likelihood phylogenetics

License:	LGPLv3+
URL:		https://github.com/beagle-dev/beagle-lib
Source0:	https://github.com/beagle-dev/beagle-lib/archive/beagle_release_%ver_sion.tar.gz

BuildRequires:	automake libtool gcc-c++ pkgconfig perl
BuildRequires:	graphviz doxygen ant

%description
BEAGLE is a high-performance library that can perform the core calculations at
the heart of most Bayesian and Maximum Likelihood phylogenetics packages. It
can make use of highly-parallel processors such as those in graphics cards
(GPUs) found in many PCs. 

The project involves an open API and fast implementations of a library for
evaluating phylogenetic likelihoods (continuous time Markov processes) of
biomolecular sequence evolution. 

The aim is to provide high performance evaluation 'services' to a wide range of
phylogenetic software, both Bayesian samplers and Maximum Likelihood
optimizers.  This allows these packages to make use of implementations that
make use of optimized hardware such as graphics processing units.


%package	devel
Summary:	Development files for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description	devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package	java
Summary:	High-performance lib for Bayesian and Maximum Likelihood phylogenetics
Requires:	%{name}%{?_isa} = %{version}-%{release} java jpackage-utils
BuildRequires:	java-devel ant jpackage-utils

%description	java
The %{name}-java package contains the Java interface for %{name}.


%prep
%setup -q -n beagle-lib-beagle_release_%ver_sion
./autogen.sh
# rogue binary
#rm -f examples/standalone/epochtest/epochtest

%build
%configure --enable-openmp # --enable-avx
make %{?_smp_mflags} all doxygen-doc
ant

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'
find -name .deps | xargs rm -r
mkdir -p $RPM_BUILD_ROOT%_mandir/man3
install -m 644 doc/man/man3/* $RPM_BUILD_ROOT%_mandir/man3
install -D lib/beagle.jar $RPM_BUILD_ROOT%_jnidir/beagle.jar
# required by mrbayes build
ln -s libhmsbeagle-2 $RPM_BUILD_ROOT%_includedir/libhmsbeagle


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%check
pushd tests
./run_tests.sh
popd

%{!?_licensedir:%global license %%doc}
%files
%doc AUTHORS
%license COPYING*
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%_libdir/pkgconfig/hmsbeagle-1.pc
%_mandir/man3/*
%doc doc/html examples

%files java
%_jnidir/beagle.jar

%changelog
* Tue Nov 24 2015 Dave Love <loveshack@fedoraproject.org> - 2.1.2-1
- New version, new URLs
- Drop Group and defattr
- Use %%license

* Sat Jun 21 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-2
- Clean .deps
- BR ant
- Don't build AVX support (at least for copr)
- Run tests

* Fri Nov 15 2013 Dave Love <d.love@liverpool.ac.uk> - 2.1-1
- Initial packaging
